module.exports = defineTest({
	description: 'handles for loop with empty head'
});
